function G=my_graph(parents, true_var)
% G=my_graph(parents, true_var)
% Create Alexander-style graphs
% parents      -- An array containing the parents of a node. parents{k} are
% the parents of node k-1 in a zero based numbering where 0 is the target
% G            -- A matrix such that G(i,j) =1 iff i->j. One-based
% numbering where 1 is the target.

if nargin<2 | isempty(true_var)
    pn=length(parents);
    G=sparse(pn, pn);
    for k=1:pn
        G(parents{k}+1,k)=1;
    end
else
    pn=length(parents)+1;
    G=sparse(pn, pn);
    G(true_var+1,1)=1; % true variables are parents of target
    for k=2:pn
        G(parents{k-1}+1,k)=1;
    end
end
