function T=target_relationship(G)
%T=target_relationship(G)
% G --  A matrix such that G(i,j) =1 iff i->j. One-based
%       numbering where 1 is the target.
% T --  A cell array strings of relationships to the target.
% Compute strings made of u and d, where u means up from the target (ancesor
% direction) and d down from the target descendent direction), for each
% node. For instance, parents are 'u', children are 'd' a,d spouses are
% 'du'.
% Stops ar depth 3. Node unrelated or related with a path to the target 
% longer than 3 get assigned the string 'xxxx'.

% Isabelle Guyon -- isabelle@clopinet.com -- Oct 2008

T=cell(size(G,1),1);
T{1}={''};

% In principle, there is a muli-label problem: some node may have more than
% one connection to the target. 
d0_nodes(1)=1; % The target
a_nodes=d0_nodes;
[d1_nodes, a_nodes, T]=pc(d0_nodes, a_nodes, T, G);
[d2_nodes, a_nodes, T]=pc(d1_nodes, a_nodes, T , G);
[d3_nodes, a_nodes, T]=pc(d2_nodes, a_nodes, T, G);

for k=1:length(T), if isempty(T{k}), T{k}={'xxxx'}; end; end



function [dd_nodes, n_nodes, T]=pc(d_nodes, o_nodes, T, G)
dd_nodes=[];
n_nodes=[];
for j=1:length(d_nodes)
    sbase=T{d_nodes(j)};
    % Parents
    for k=1:length(sbase)
        pbase{k}=[sbase{k} 'u'];
    end
    p=setdiff(find(G(:,d_nodes(j))==1)', o_nodes);
    for k=1:length(p), T{p(k)}=[T{p(k)} pbase]; end
    dd_nodes=[dd_nodes p];
    % Children
    for k=1:length(sbase)
        cbase{k}=[sbase{k} 'd'];
    end
    c=setdiff(find(G(d_nodes(j),:)==1), o_nodes);
    for k=1:length(c), T{c(k)}=[T{c(k)} cbase]; end
    dd_nodes=[dd_nodes c];
    dd_nodes=setdiff(unique(dd_nodes), o_nodes);
    n_nodes=union(o_nodes, dd_nodes);
end

for k=1:length(T)
    T{k}=unique(T{k});
end
